@@ -23,10 +23,15 @@ def match_tag_to_languages(tags: List[str]) -> List[str]:
     weak_guesses = set()
     for tag in tags:
         for key, value in RELATED_TAGS.items():
-            if tag in value:
+            if tag in value[0:3]:
                 weak_guesses.add(key)
 
-    return list(strong_guesses) + list(weak_guesses)
+    new_weak_guesses = []
+    for guess in weak_guesses:
+        if guess not in strong_guesses:
+            new_weak_guesses.append(guess)
+    return list(strong_guesses) + list(new_weak_guesses)
+
 
 # Old algo
 # def match_tag_to_language(tags: List[str]) -> Optional[Tuple[str, str]]:
